Index: src/compiler/frame-states.h |
diff --git a/src/compiler/frame-states.h b/src/compiler/frame-states.h |
index 8ab4d138d7d3fd76eedc6efbeb023254c46beb79..ddb55c35d245ca6286f0ef11b9ffabb384a471ac 100644 |
--- a/src/compiler/frame-states.h |
+++ b/src/compiler/frame-states.h |
@@ -76,9 +76,10 @@ class OutputFrameStateCombine { |
// The type of stack frame that a FrameState node represents. |
enum class FrameStateType { |
- kJavaScriptFunction, // Represents an unoptimized JavaScriptFrame. |
- kArgumentsAdaptor, // Represents an ArgumentsAdaptorFrame. |
- kConstructStub // Represents a ConstructStubFrame. |
+ kJavaScriptFunction, // Represents an unoptimized JavaScriptFrame. |
+ kInterpretedFunction, // Represents an InterpretedFrame. |
+ kArgumentsAdaptor, // Represents an ArgumentsAdaptorFrame. |
+ kConstructStub // Represents a ConstructStubFrame. |
}; |
@@ -108,6 +109,11 @@ class FrameStateFunctionInfo { |
return context_calling_mode_; |
} |
+ static bool IsJSFunctionType(FrameStateType type) { |
+ return type == FrameStateType::kJavaScriptFunction || |
+ type == FrameStateType::kInterpretedFunction; |
+ } |
+ |
private: |
FrameStateType const type_; |
int const parameter_count_; |